<?php

namespace Drupal\modeler_api\Form;

use Drupal\Component\Serialization\Json;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Url;
use Drupal\modeler_api\Plugin\modeler_api_model_owner\ModelOwnerInterface;

/**
 * Provides action button for modeler edit forms.
 */
trait EditFormActionButtonsTrait {

  use StringTranslationTrait;

  /**
   * Provides all the action buttons for modelers.
   *
   * @return array
   *   The render array for action buttons.
   */
  protected function actionButtons(ModelOwnerInterface $owner, string $id): array {
    $basePath = $owner->configEntityBasePath();
    if ($basePath === NULL) {
      return [];
    }
    $modelType = $owner->configEntityTypeId();
    $options = [
      'query' => [
        'destination' => Url::fromRoute('entity.' . $modelType . '.edit_form', [$modelType => $id])->toString(),
      ],
    ];
    return [
      '#type' => 'actions',
      'save' => [
        '#type' => 'submit',
        '#value' => $this->t('Save'),
        '#attributes' => [
          'class' => ['button--primary', 'modeler_api-save'],
        ],
      ],
      'layout_process' => [
        '#type' => 'submit',
        '#value' => $this->t('Layout model'),
        '#attributes' => [
          'class' => ['modeler_api-layout-process'],
        ],
      ],
      'close' => [
        '#type' => 'submit',
        '#value' => $this->t('Close'),
        '#attributes' => [
          'class' => ['modeler_api-close'],
        ],
      ],
      'export_archive' => [
        '#type' => 'link',
        '#url' => Url::fromRoute('entity.' . $modelType . '.export', [$modelType => $id], $options),
        '#title' => $this->t('Export'),
        '#attributes' => [
          'class' => ['button button--small', 'modeler_api-export-archive'],
        ],
      ],
      'export_recipe' => [
        '#type' => 'link',
        '#url' => Url::fromRoute('entity.' . $modelType . '.export_recipe', [$modelType => $id], $options),
        '#title' => $this->t('Export Recipe'),
        '#attributes' => [
          'class' => ['button button--small', 'modeler_api-export-recipe use-ajax'],
          'data-dialog-options' => Json::encode([
            'width' => 400,
            'title' => $this->t('Export Recipe'),
          ]),
          'data-dialog-type' => 'modal',
        ],
        '#attached' => [
          'library' => [
            'core/drupal.dialog.ajax',
          ],
        ],
      ],
      'export_svg' => [
        '#type' => 'submit',
        '#value' => $this->t('Export SVG'),
        '#attributes' => [
          'class' => ['button button--small', 'modeler_api-export-svg'],
        ],
      ],
    ];
  }

}
